@@ -832,9 +832,9 @@ class TestObjEqualPrims(_BaseTestCase):
 
 class TestObjMethodOverrides(test.NoDBTestCase):
     def test_obj_reset_changes(self):
-        args = inspect.getargspec(base.MasakariObject.obj_reset_changes)
+        args = inspect.getfullargspec(base.MasakariObject.obj_reset_changes)
         obj_classes = base.MasakariObjectRegistry.obj_classes()
         for obj_name in obj_classes:
             obj_class = obj_classes[obj_name][0]
             self.assertEqual(args,
-                    inspect.getargspec(obj_class.obj_reset_changes))
+                    inspect.getfullargspec(obj_class.obj_reset_changes))
